<?
    $structures["zones"] = array(
	"title"=>"Zones",
	"object"=>"zones",
	"show_id"=>1,
	"profile"=>"ADMIN_HOSTS",

	"fields"=>array(
	    "zone"=>array(	"name"=>"Zone",		"type"=>"textbox",	"size"=>20),
	    "shortname"=>array(	"name"=>"ShortName",	"type"=>"textbox",	"size"=>20),
	    "image"=>array(	"name"=>"Image",	"type"=>"textbox",	"size"=>20),
	    //"admin_status"=>array(	"name"=>"Network Discovery Enabled",	"type"=>"checkbox"),
	    //"seeds"=>array(	"name"=>"Network Discovery Seeds",	"type"=>"textbox",	"size"=>60),
	    //"communities"=>array(	"name"=>"SNMP Communities",		"type"=>"textbox",	"size"=>60),
	    //"max_deep"=>array(	"name"=>"Max Hops",		"type"=>"select",	"func"=>"select_nad_deep"),
	    //"refresh"=>array(	"name"=>"Re-scan every (secs)",	"type"=>"select",	"func"=>"select_nad_refresh"),
	    NULL)
	);

    $structures["graph_types"] = array(
	"title"=>"Graph Types",
	"object"=>"graph_types",
	"show_id"=>1,
	"hide_record_one"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",		"type"=>"textbox",	"size"=>20),
	    "type"=>array(		"name"=>"Interface Type",	"type"=>"select",	"func"=>"select_interface_types", "view"=>"types_description", "size"=>30),
	    "allow_aggregation"=>array(	"name"=>"Allow Aggregation",	"type"=>"checkbox"),

	    "graph1"=>array(	"name"=>"Graph 1",	"type"=>"textbox",	"size"=>20),
	    "sizex1"=>array(	"name"=>"Width 1",	"type"=>"textbox",	"size"=>20),
	    "sizey1"=>array(	"name"=>"Height 1",	"type"=>"textbox",	"size"=>20),

	    "graph2"=>array(	"name"=>"Graph 2",	"type"=>"textbox",	"size"=>20),
	    "sizex2"=>array(	"name"=>"Width 2",	"type"=>"textbox",	"size"=>20),
	    "sizey2"=>array(	"name"=>"Height 2",	"type"=>"textbox",	"size"=>20),
	    NULL)
	);

    $structures["clients"] = array(
	"title"=>"Customers",
	"object"=>"clients",
	"show_id"=>1,
	"hide_record_one"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_HOSTS",

	"fields"=>array(
	    "name"=>array(	"name"=>"Customer Name",	"type"=>"textbox",	"size"=>20),
	    "shortname"=>array(	"name"=>"Customer ShortName",	"type"=>"textbox",	"size"=>20),
	    "username"=>array(	"name"=>"Username",		"type"=>"textbox",	"size"=>60),
	    "password"=>array(	"name"=>"Password",		"type"=>"textbox",	"size"=>20),
	    NULL)
	);

    $structures["autodiscovery"] = array(
	"title"=>"Autodiscovery",
	"object"=>"autodiscovery",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_HOSTS",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",		"type"=>"textbox",	"size"=>30),
	    "poller_default"=>array(	"name"=>"Default Poller",	"type"=>"checkbox"),
	    "permit_add"=>array(	"name"=>"Permit Add",		"type"=>"checkbox"),
	    "permit_del"=>array(	"name"=>"Permit Delete",	"type"=>"checkbox"),
	    "alert_del"=>array(		"name"=>"Alert on Delete",	"type"=>"checkbox"),
	    "permit_mod"=>array(	"name"=>"Permit Modify",	"type"=>"checkbox"),
	    "permit_disable"=>array(	"name"=>"Permit Disable",	"type"=>"checkbox"),
	    "skip_loopback"=>array(	"name"=>"Skip LoopBack",	"type"=>"checkbox"),
	    "check_state"=>array(	"name"=>"Check State",		"type"=>"checkbox"),
	    "check_address"=>array(	"name"=>"Check Valid Address",	"type"=>"checkbox"),
	    NULL)
	);


    $structures["severity"] = array(
	"title"=>"Severities",
	"object"=>"severity",
	"show_id"=>0,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "level"=>array(	"name"=>"Level",		"type"=>"textbox",	"size"=>3),
	    "severity"=>array(	"name"=>"Description",		"type"=>"textbox",	"size"=>20),
	    "bgcolor"=>array(	"name"=>"Background Color",	"type"=>"colorbox"),
	    "fgcolor"=>array(	"name"=>"Foreground Color",	"type"=>"colorbox"),
	    NULL)
	);


    $structures["traps_types"] = array(
	"title"=>"SNMP Trap Events Types",
	"object"=>"traps_types",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "match_oid"=>array(	"name"=>"OID Match",		"type"=>"textbox",	"size"=>100),
	    "interface"=>array(	"name"=>"Interface Field",	"type"=>"textbox",	"size"=>10),
	    "username"=>array(	"name"=>"Username Field",	"type"=>"textbox",	"size"=>10),
	    "state"=>array(	"name"=>"State Field",		"type"=>"textbox",	"size"=>10),
	    "info"=>array(	"name"=>"Extra Info Field",	"type"=>"textbox",	"size"=>10),
	    "type"=>array(	"name"=>"Event Type",		"type"=>"select",	"func"=>"select_event_types",	"view"=>"types_description", "size"=>30),
	    NULL)
	);

    $structures["syslog_types"] = array(
	"title"=>"Syslog Events Types",
	"object"=>"syslog_types",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "match_text"=>array(	"name"=>"Text Match",	"type"=>"textbox",	"size"=>70),
	    "interface"=>array(	"name"=>"Interface Field",	"type"=>"textbox",	"size"=>10),
	    "username"=>array(	"name"=>"Username Field",	"type"=>"textbox",	"size"=>10),
	    "state"=>array(	"name"=>"State Field",		"type"=>"textbox",	"size"=>10),
	    "info"=>array(	"name"=>"Extra Info Field",	"type"=>"textbox",	"size"=>10),
	    "type"=>array(	"name"=>"Event Type",		"type"=>"select",	"func"=>"select_event_types",	"view"=>"types_description", "size"=>30),
	    "pos"=>array(	"name"=>"Position",		"type"=>"textbox",	"size"=>3),
	    NULL)
	);

    $structures["event_types"] = array(
	"title"=>"Event Types",
	"object"=>"event_types",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",			"type"=>"textbox",	"size"=>30),
	    "severity"=>array(	"name"=>"Severity",				"type"=>"select",	"func"=>"select_severity", "view"=>"severity_description", "size"=>30),
	    "text"=>array(	"name"=>"Event Text",				"type"=>"textbox",	"size"=>60),
	    "show_default"=>array(	"name"=>"Show in Event Viewer?",	"type"=>"select", 	"func"=>"select_events_show", "size"=>10),
	    "generate_alarm"=>array(	"name"=>"Event Generates an Alarm?",	"type"=>"checkbox"),
	    "alarm_up"=>array(	"name"=>"Different Alarm for Up Event",		"type"=>"select",	"func"=>"select_event_types", "params"=>array(1,NULL,NULL,array(NULL,array("show_unknown"=>1))), "view"=>"alarm_up_description", "size"=>30),
	    "alarm_duration"=>array(	"name"=>"Alarm Duration",		"type"=>"select",	"func"=>"select_alarm_duration", "size"=>30),
	    "show_host"=>	array(	"name"=>"Show Host Field?",		"type"=>"checkbox"),
	    NULL)
	);

    $structures["interface_types"] = array(
	"title"=>"Interface Types",
	"object"=>"interface_types",
	"show_id"=>1,
	"hide_record_one"=>1,

	"action_type"=>2,
	"split"=>"interface_types_fields",
	"split_standard"=>1,
	"split_view_name"=>"Fields",

	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(		"name"=>"Description",			"type"=>"textbox",	"size"=>30),

	    "autodiscovery_enabled"=>array(	"name"=>"Autodiscovery Enabled",	"type"=>"checkbox"),
	    "autodiscovery_validate"=>array(	"name"=>"Validate in Autodiscovery",	"type"=>"checkbox"),
	    "autodiscovery_function"=>array(	"name"=>"Autodiscovery Function (Internal)",	"type"=>"textbox", "size"=>40),
	    "autodiscovery_parameters"=>array(	"name"=>"Autodiscovery Parameters",	"type"=>"textbox",	"size"=>30),
	    "autodiscovery_default_poller"=>array(	"name"=>"Autodiscovery Default Poller",	"type"=>"select",	"func"=>"select_pollers_groups", "view"=>"poller_default", "size"=>30),
	    
	    "update_handler"=>	array(	"name"=>"Internal Update Handler","type"=>"textbox", "size"=>20),

	    "allow_manual_add"=>array(		"name"=>"Manual Interface Add",		"type"=>"checkbox"),

	    "break_by_card"=>array(	"name"=>"Break by Card",	"type"=>"checkbox"),
	    "have_tools"=>array(	"name"=>"Have Tools",		"type"=>"checkbox"),
	    "have_graph"=>array(	"name"=>"Have Graph",		"type"=>"checkbox"),

	    "graph_default"=>array(	"name"=>"Default Graph",	"type"=>"select",	"func"=>"select_graph_types", "view"=>"graph_types_description", "size"=>30),
	    "sla_default"=>array(	"name"=>"Default SLA",		"type"=>"select",	"func"=>"select_slas", "view"=>"slas_description", "size"=>30),
	
	    "rrd_structure_rra"=>array(	"name"=>"RRDTool Structure RRA","type"=>"memobox", "width"=>40, "height"=>5, "size"=>40),
	    "rrd_structure_res"=>array(	"name"=>"RRDTool Resolution",	"type"=>"textbox", "size"=>20),
	    "rrd_structure_step"=>array(	"name"=>"RRDTool Step",	"type"=>"textbox", "size"=>10),

	    NULL)
	);

    $structures["filters"] = array(
	"title"=>"Filters",
	"object"=>"filters",
	"show_id"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"action_type"=>2,
	"split"=>"filters_cond",
	"split_standard"=>1,

	"fields"=>array("description"=>array(	"name"=>"Description",		"type"=>"textbox",	"size"=>30))
	);


    $structures["filters_cond"] = array(
	"title"=>"Filters Conditions",
	"object"=>"filters_cond",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "filter_id"=>array(	"name"=>"Filter",	"type"=>"select",	"func"=>"select_filters",	"size"=>30, "view"=>"filter_description"),
	    "pos"=>array(	"name"=>"Position",		"type"=>"textbox", "size"=>5),
	    "field_id"=>array(	"name"=>"Field",	"type"=>"select",	"func"=>"select_filters_fields",	"size"=>30, "view"=>"field_description"),
	    "op"=>array(	"name"=>"Operator",	"type"=>"select",	"func"=>"select_op",	"size"=>30, "view"=>""),
	    "value"=>array(	"name"=>"Value",	"type"=>"select",	"func"=>"get_filter_option",	"size"=>30, "view"=>"","params_field"=>"field_name"),
	    NULL)
	);

    $structures["filters_fields"] = array(
	"title"=>"Filter Fields",
	"object"=>"filters_fields",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"	=>array(	"name"=>"Description",	"type"=>"textbox",	"size"=>30),
	    "field"		=>array(	"name"=>"Field Name",	"type"=>"textbox",	"size"=>30),
	    NULL)
	);

    $structures["slas"] = array(
	"title"=>"SLAs",
	"object"=>"slas",
	"show_id"=>1,
	"action_type"=>2,
	"split"=>"slas_sla_cond",
	"split_standard"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox",	"size"=>30),
	    "interface_type"=>array(	"name"=>"Interface Type",	"type"=>"select",	 "func"=>"select_interface_types", "view"=>"interface_type_description", "size"=>30),
	    "event_type"=>array(	"name"=>"Event Type",	"type"=>"select",		"func"=>"select_event_types", "view"=>"types_description", "size"=>30),
	    "state"=>array(	"name"=>"Alarm State",	"type"=>"select",		"func"=>"select_alarm_states", "view"=>"state_description", "size"=>60),
	    "info"=>array(	"name"=>"Event Text",	"type"=>"textbox",	"size"=>30),
	    "threshold"=>array(	"name"=>"Threshold % (for Reports)",	"type"=>"textbox",	"size"=>3),
	    NULL)
	);

    $structures["slas_cond"] = array(
	"title"=>"SLA Individual Conditions",
	"object"=>"slas_cond",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "event"=>array(	"name"=>"Show Info",	"type"=>"textbox",	"size"=>30),
	    "condition"=>array(	"name"=>"Condition",	"type"=>"textbox",	"size"=>100),
	    "variable_show"=>array(	"name"=>"Show Expression",	"type"=>"textbox",	"size"=>100),
	    "variable_show_info"=>array(	"name"=>"Show Unit",	"type"=>"textbox",	"size"=>30),
	    NULL)
	);

    $structures["maps"] = array(
	"title"=>"SubMaps (Interface Groups)",
	"object"=>"maps",
	"show_id"=>1,
	"action_type"=>2,
	"split"=>"maps_interfaces",
	"split_standard"=>1,
	"profile"=>"ADMIN_HOSTS",

	"fields"=>array(
	    "name"=>array(	"name"=>"Map Name",	"type"=>"textbox","size"=>30),
	    "parent"=>array(	"name"=>"Parent Map",	"type"=>"select",	"func"=>"select_maps", "view"=>"parent_name", "size"=>30),
	    "color"=>array(	"name"=>"Background Color",	"type"=>"colorbox"),
	    NULL)
	);

    $structures["alarm_states"] = array(
	"title"=>"Alarm States (and Sounds)",
	"object"=>"alarm_states",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "activate_alarm"=>array(	"name"=>"Alarm Level",	"type"=>"textbox", "size"=>5),
	    "sound_in"=>array(		"name"=>"Sound In",	"type"=>"textbox","size"=>30),
	    "sound_out"=>array(		"name"=>"Sound Out",	"type"=>"textbox","size"=>30),
	    "state"=>array(		"name"=>"Internal State", "type"=>"select", "func"=>"select_alarm_states_states", "view_params"=>1),
	    NULL)
	);

    $structures["maps_interfaces"] = array(
	"title"=>"SubMaps/Interfaces",
	"object"=>"maps_interfaces",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_HOSTS",
	"no_records_message"=>"No Interfaces Found in this Map.",

	"fields"=>array(
	    "map"=>array(	"name"=>"Map Name",	"type"=>"select",	"func"=>"select_maps",		"view"=>"map_name",	"size"=>30),
	    "interface"=>array(	"name"=>"Interface",	"type"=>"select",	"func"=>"select_interfaces",	"view"=>"interface_description",	"size"=>60, "params"=>array(6)),
	    "x"=>	array(	"name"=>"X",		"type"=>"textbox","size"=>5),
	    "y"=>	array(	"name"=>"Y",		"type"=>"textbox","size"=>5),
	    NULL)
	);

    $structures["pollers"] = array(
	"title"=>"Pollers",
	"object"=>"pollers",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "name"=>array(		"name"=>"Name (Match RRD Struct DS)",	"type"=>"textbox", "size"=>30),
	    "command"=>array(		"name"=>"Poller Command (file)",	"type"=>"textbox","size"=>30),
	    "parameters"=>array(	"name"=>"Parameters",	"type"=>"textbox","size"=>30),
	    NULL)
	);

    $structures["pollers_backend"] = array(
	"title"=>"Pollers Backends",
	"object"=>"pollers_backend",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "command"=>array(		"name"=>"Poller Command (file)",	"type"=>"textbox","size"=>30),
	    "parameters"=>array(	"name"=>"Parameters",	"type"=>"textbox","size"=>30),
	    "type"=>array(		"name"=>"Type (is Status?)",		"type"=>"checkbox"),
	    NULL)
	);

    $structures["pollers_groups"] = array(
	"title"=>"Poller Groups",
	"object"=>"pollers_groups",
	"show_id"=>1,
	"action_type"=>2,
	"split"=>"pollers_poller_groups",
	"split_standard"=>1,
	"profile"=>"ADMIN_SYSTEM",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "interface_type"=>array(	"name"=>"Interface Type",	"type"=>"select",	"func"=>"select_interface_types",	"size"=>30, "view"=>"type_description"),
	    NULL)
	);

    $structures["pollers_poller_groups"] = array(
	"title"=>"Poller Group - Pollers/Backend Relation",
	"object"=>"pollers_poller_groups",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "poller_group"=>array(	"name"=>"Poller Group",	"type"=>"select",	"func"=>"select_pollers_groups",	"size"=>30, "view"=>"group_description"),
	    "pos"=>array(	"name"=>"Position",	"type"=>"textbox", "size"=>3),
	    "poller"=>array(	"name"=>"Poller",		"type"=>"select",	"func"=>"select_pollers",		"size"=>30, "view"=>"poller_description"),
	    "backend"=>array(	"name"=>"Backend",	"type"=>"select",	"func"=>"select_pollers_backend",	"size"=>30, "view"=>"backend_description"),
	    NULL)
	);

    $structures["slas_sla_cond"] = array(
	"title"=>"SLAs - SLA Conditions Relation",
	"object"=>"slas_sla_cond",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "sla"=>array(	"name"=>"SLA",		"type"=>"select",	"func"=>"select_slas",		"size"=>30, "view"=>"sla_description"),
	    "pos"=>array(	"name"=>"Position",	"type"=>"textbox", "size"=>3),
	    "cond"=>array(	"name"=>"Condition",	"type"=>"select",	"func"=>"select_slas_cond",	"size"=>30, "view"=>"cond_description"),
	    "show_in_result"=>array(	"name"=>"Show",		"type"=>"checkbox"),
	    NULL)
	);

    $structures["profiles_values"] = array(
	"title"=>"Profiles Option Values",
	"object"=>"profiles_values",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_USERS",
	
	"fields"=>array(
	    "profile_option"=>array(	"name"=>"Option",	"type"=>"select",	"func"=>"select_profiles_options",	"size"=>30, "view"=>"option_description"),
	    "description"=>array(	"name"=>"Description",		"type"=>"textbox", "size"=>30),
	    "value"=>array(	"name"=>"Value",		"type"=>"textbox", "size"=>30),
	    NULL)
	);

    $structures["actions"] = array(
	"title"=>"Actions",
	"object"=>"actions",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"	 =>array(	"name"=>"Description",			"type"=>"textbox", "size"=>30),
	    "command"		 =>array(	"name"=>"Command",			"type"=>"textbox", "size"=>30),
	    "internal_parameters"=>array(	"name"=>"Interal Parameters",		"type"=>"textbox", "size"=>100),
	    "user_parameters"	 =>array(	"name"=>"User Parameters",		"type"=>"textbox", "size"=>100),
	    NULL)
	);

    $structures["triggers"] = array(
	"title"=>"Triggers",
	"object"=>"triggers",
	"show_id"=>1,
	"action_type"=>2,
	"hide_record_one"=>1,
	"split"=>"triggers_rules",
	"profile"=>"ADMIN_SYSTEM",
	"split_view_name"=>"View Rules",

	"fields"=>array(
	    "description"=>array(	"name"=>"Description",		"type"=>"textbox", "size"=>30),
	    "type"=>array(		"name"=>"Type",			"type"=>"select", "func"=>"select_triggers_types"),
	    NULL)
	);

    $structures["triggers_users"] = array(
	"title"=>"User Triggers",
	"object"=>"triggers_users",
	"show_id"=>0,
	"action_type"=>1,
	"filter_by_user"=>"user_id",
	
	"fields"=>array(
	    "trigger_id"=>array(	"name"=>"Trigger",	"type"=>"select",	"func"=>"select_triggers",	"size"=>30, "view"=>"trigger_description"),
	    "active"=>array(	    	"name"=>"Active",	 	"type"=>"checkbox"),
	    NULL)
	);

    $structures["triggers_users_admin"] = array(
	"title"=>"User Triggers",
	"object"=>"triggers_users",
	"show_id"=>1,
	"action_type"=>1,
	"profile"=>"ADMIN_USERS",
	
	"fields"=>array(
	    "user_id"=>array(		"name"=>"Username", 	"type"=>"select",	"func"=>"select_users",		"size"=>30, "view"=>"user_description"),
	    "trigger_id"=>array(	"name"=>"Trigger",	"type"=>"select",	"func"=>"select_triggers",	"size"=>30, "view"=>"trigger_description"),
	    "active"=>array(	    	"name"=>"Active",	 	"type"=>"checkbox"),
	    NULL)
	);

    $structures["hosts_config_types"] = array(
	"title"=>"Host Config Commands",
	"object"=>"hosts_config_types",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>60),
	    "command"=>array(		"name"=>"Command",	"type"=>"textbox","size"=>30),
	    NULL)
	);

    $structures["interface_types_field_types"] = array(
	"title"=>"Interface Field Types",
	"object"=>"interface_types_field_types",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",
	
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "handler"=>array(		"name"=>"Handler",	"type"=>"textbox","size"=>30),
	    NULL)
	);

    $structures["interface_types_fields"] = array(
	"title"=>"Interface Type Fields",
	"object"=>"interface_types_fields",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",

	//add filter
	"filter_field"=>"itype",
		
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "name"=>array(		"name"=>"Internal Name",	"type"=>"textbox","size"=>30),
	    "pos"=>array(		"name"=>"Position",	"type"=>"textbox","size"=>3),
	    "itype"=>array(		"name"=>"Interface Type",	"type"=>"select",	 "func"=>"select_interface_types", "view"=>"itype_description", "size"=>30),
	    "ftype"=>array(		"name"=>"Field Type",	"type"=>"select",	 "func"=>"select_interface_types_field_types", "view"=>"ftype_description", "size"=>30),
	    "showable"=>array(	    	"name"=>"Show",	 	"type"=>"select",	 "func"=>"select_interface_types_field_show"),
	    "overwritable"=>array(	"name"=>"Overwritable", 	"type"=>"checkbox"),
	    "tracked"=>array(	    	"name"=>"Tracked", 	"type"=>"checkbox"),
	    "default_value"=>array(	"name"=>"Default Value",	"type"=>"select",	"func"=>"interface_value_control", "params_field"=>"ftype_handler", "size"=>30),
	    "ftype_handler"=>array(    	"name"=>"Field Type Handler",  "type"=>"hidden"),
	    NULL)
	);

    $structures["tools"] = array(
	"title"=>"Tools",
	"object"=>"tools",
	"show_id"=>1,
	"action_type"=>1,
	"hide_record_one"=>1,
	"profile"=>"ADMIN_SYSTEM",

	//add filter
	"filter_field"=>"itype",
		
	"fields"=>array(
	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
	    "name"=>array(		"name"=>"Internal Name",	"type"=>"textbox","size"=>30),
	    "pos"=>array(		"name"=>"Position",	"type"=>"textbox","size"=>3),
	    "itype"=>array(		"name"=>"Interface Type",	"type"=>"select",	 "func"=>"select_interface_types", "view"=>"itype_description", "size"=>30),
	    "file_group"=>array(	"name"=>"File Group",	"type"=>"textbox","size"=>30),
	    "allow_set"=>array(		"name"=>"Allow Set", 	"type"=>"checkbox"),
	    "allow_get"=>array(		"name"=>"Allow Get", 	"type"=>"checkbox"),
	    NULL)
	);
    

    if ($admin_structure=="list_all") { 
	foreach (array_keys($structures) as $aux) echo "<a href='adm_standard.php?admin_structure=$aux'>$aux</a>\n<br>"; 
	die();
    } else 
	if (is_array($structures[$admin_structure])) $structure = $structures[$admin_structure];
	    else die ("<H1> Admin Structure Not Found </H1></HTML>");
?>
